<?php

/**
 *  Copyright (C) 2020 OTP Mobil Kft.
 *
 *  PHP version 7
 *
 *  This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  SDK
 * @package   SimplePayV21_SDK
 * @author    SimplePay IT Support <itsupport@otpmobil.com>
 * @copyright 2020 OTP Mobil Kft.
 * @license   http://www.gnu.org/licenses/gpl-3.0.html  GNU GENERAL PUBLIC LICENSE (GPL V3.0)
 * @link      http://simplepartner.hu/online_fizetesi_szolgaltatas.html
 */

//Optional error riporting
error_reporting(E_ALL);
ini_set('display_errors', '1');

 //Import config data
require_once 'src/config.php';

//Import SimplePayment class
require_once 'src/SimplePayV21.php';

//Import SimplePayV21CardStorage
require_once 'src/SimplePayV21CardStorage.php';

$trx = new SimplePayDo;

$trx->addConfig($config);


//account
//-----------------------------------------------------------------------------------------
$trx->addConfigData('merchantAccount', $_REQUEST['merchant']);


//add merchant transaction ID
//-----------------------------------------------------------------------------------------
$trx->addData('orderRef', str_replace(array('.', ':', '/'), "", @$_SERVER['SERVER_ADDR']) . @date("U", time()) . rand(1000, 9999));


// METHODS
//-----------------------------------------------------------------------------------------
$trx->addData('methods', array('CARD'));


//add currency
//-----------------------------------------------------------------------------------------
$trx->addData('currency', 'HUF');


//ORDER PRICE/TOTAL
//-----------------------------------------------------------------------------------------
$trx->addData('total', 5);


//CUSTOMER
//customer's name
//-----------------------------------------------------------------------------------------
//$trx->addData('customer', 'DO tester');


//customer's email
//-----------------------------------------------------------------------------------------
$trx->addData('customerEmail', 'sdk_test@otpmobil.com');


//For all type transaction: SimplePay oneClick, legacy oneClick, legacyRecurring, MW registered card, API v1 registered card
//-----------------------------------------------------------------------------------------
if (isset($_REQUEST['cardId'])) {
    $trx->addData('cardId', $_REQUEST['cardId']);
}


// For SimplePay oneClick transaction only
//-----------------------------------------------------------------------------------------
if (isset($_REQUEST['cardSecret'])) {
    $trx->addData('cardSecret', $_REQUEST['cardSecret']);
}


// For legacyRecurring transaction only
//-----------------------------------------------------------------------------------------
if (isset($_REQUEST['legacyRecurring'])) {
    $trx->addData('legacyRecurring', $_REQUEST['legacyRecurring']);
}


//3DS section
//-----------------------------------------------------------------------------------------
$type = 'CIT';
if (isset($_REQUEST['type'])) {
    $type = $_REQUEST['type'];
}
$trx->addData('type', $type);


// customer's registration mehod
// 01: guest
// 02: registered
// 05: third party
//-----------------------------------------------------------------------------------------
$trx->addData('threeDSReqAuthMethod', '02');


//transactions with user presence
//-----------------------------------------------------------------------------------------
if ($type == 'CIT') {
    if (isset($_REQUEST['server'])) {
        $serverData = json_decode(base64_decode($_REQUEST['server']));
        $trx->addGroupData('browser', 'accept', $serverData->accept);
        $trx->addGroupData('browser', 'agent', $serverData->agent);
        $trx->addGroupData('browser', 'ip', $serverData->ip);
    }

    if (isset($_REQUEST['browser'])) {
        $browserData = json_decode(base64_decode($_REQUEST['browser']));
        $trx->addGroupData('browser', 'java', $browserData->java);
        $trx->addGroupData('browser', 'lang', $browserData->lang);
        $trx->addGroupData('browser', 'color', $browserData->color);
        $trx->addGroupData('browser', 'height', $browserData->height);
        $trx->addGroupData('browser', 'width', $browserData->width);
        $trx->addGroupData('browser', 'tz', $browserData->tz);
    }
    
    // Challenge REDIRECT URL for CIT transactions
    //-----------------------------------------------------------------------------------------
    // common URL for all result
    $trx->addData('url', $config['URL']);
}


//start do
//-----------------------------------------------------------------------------------------
$v2DoResult = $trx->runDo();


//start challenge
//-----------------------------------------------------------------------------------------
$transactionBase = $trx->getTransactionBase();
if ($trx->config['autoChallenge'] && isset($v2DoResult['redirectUrl']) && $transactionBase['type'] === 'CIT') {
    $trx->formDetails['element'] = 'auto';
    $trx->challenge($v2DoResult);
}


// test data
//-----------------------------------------------------------------------------------------
print "API REQUEST";
print "<pre>";
print_r($trx->getTransactionBase());
print "</pre>";

print "API RESULT";
print "<pre>";
print_r($trx->getReturnData());
print "</pre>";

