<?php


/**
 *  Copyright (C) 2020 OTP Mobil Kft.
 *
 *  PHP version 7
 *
 *  This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see http://www.gnu.org/licenses
 *
 * @category  SDK
 * @package   SimplePayV21_SDK
 * @author    SimplePay IT Support <itsupport@otpmobil.com>
 * @copyright 2020 OTP Mobil Kft.
 * @license   http://www.gnu.org/licenses/gpl-3.0.html  GNU GENERAL PUBLIC LICENSE (GPL V3.0)
 * @link      http://simplepartner.hu/online_fizetesi_szolgaltatas.html
 */
 
//Optional error riporting
error_reporting(E_ALL);
ini_set('display_errors', '1');

//Import config data    
require_once 'src/config.php';

//Import SimplePayment class
require_once 'src/SimplePayV21.php';

$trx = new SimplePayStart;

// Recurring back page
//----------------------------------------------------------------------------------------- 
$config['URL'] = 'http://' . $_SERVER['HTTP_HOST'] . '/v21_200825/backstorage.php';

$trx->addConfig($config);

$currency = 'HUF';
$trx->addData('currency', $currency);


/**
 *  Card storage options
 */
if (isset($_REQUEST['oneclick'])) {

    // OneClick card storage
    //----------------------------------------------------------------------------------------- 

    $trx->addData('cardSecret', 'SECRET');

} elseif (isset($_REQUEST['recurring'])) {
    
    // Recurring card storage
    //----------------------------------------------------------------------------------------- 

    //number of claimed tokens (min 1, max 24)
    $trx->addGroupData('recurring', 'times', 4);
    //tokens expiration (min 1 hour, max 2 years)
    $trx->addGroupData('recurring', 'until', '2021-12-01T18:00:00+02:00');
    //Max paymentable amount per token (per transaction) in the currency of the account
    $trx->addGroupData('recurring', 'maxAmount', 50);

} elseif (isset($_REQUEST['legacyoneclick'])) {

    // Legacy OneClick card storage
    //-----------------------------------------------------------------------------------------     
    
    $trx->addData('legacyCardRegister', true);
    
} elseif (isset($_REQUEST['legacyrecurring'])) {

    // Legacy Recurring card storage
    //-----------------------------------------------------------------------------------------     
    
    $trx->addData('legacyRecurring', true);
    
}


// ONLY CARD REGISTRATION
// in case of twostep card registration without finish
//-----------------------------------------------------------------------------------------
//$trx->addData('onlyCardReg', true);


//ORDER PRICE/TOTAL
//-----------------------------------------------------------------------------------------
$trx->addData('total', '25');    

//ORDER ITEMS
//-----------------------------------------------------------------------------------------
/*
$trx->addItems(
    array(
        'ref' => 'Product ID 1',
        'title' => 'Product name 1',
        'description' => 'Product description 1',
        'amount' => '1',
        'price' => '15',
        'tax' => '0',
        )
);

$trx->addItems(
    array(
        'ref' => 'Product ID 2',
        'title' => 'Product name 2',
        'description' => 'Product description 2',
        'amount' => '2',
        'price' => '5',
        'tax' => '0',
        )
);        
*/    


// SHIPPING COST
//-----------------------------------------------------------------------------------------
//$trx->addData('shippingCost', 20);


// DISCOUNT
//-----------------------------------------------------------------------------------------
//$trx->addData('discount', 10);


// ORDER REFERENCE NUMBER 
// uniq oreder reference number in the merchant system
//-----------------------------------------------------------------------------------------
$trx->addData('orderRef', str_replace(array('.', ':', '/'), "", @$_SERVER['SERVER_ADDR']) . @date("U", time()) . rand(1000, 9999));


// CUSTOMER
// customer's name
//-----------------------------------------------------------------------------------------
//$trx->addData('customer', 'v2.1 SimplePay Card Storage Teszt');


// customer's registration mehod
// 01: guest
// 02: registered
// 05: third party
//-----------------------------------------------------------------------------------------
$trx->addData('threeDSReqAuthMethod', '02');


// EMAIL
// customer's email
//-----------------------------------------------------------------------------------------
$trx->addData('customerEmail', 'sdk_test@otpmobil.com');


// LANGUAGE
// HU, EN, DE, etc.
//----------------------------------------------------------------------------------------- 
$trx->addData('language', 'HU');


// TWO STEP
// true, or false
// The this field does not exist is equal false value 
// possibility of two step needs IT support setting
//-----------------------------------------------------------------------------------------
/*
$twoStep = false;
if (isset($_REQUEST['twoStep'])) {
    $twoStep = true;
}
$trx->addData('twoStep', $twoStep);
*/


// TIMEOUT
// 2018-09-15T11:25:37+02:00
//-----------------------------------------------------------------------------------------
$timeoutInSec = 600;
$timeout = @date("c", time() + $timeoutInSec);
$trx->addData('timeout', $timeout);

                        
// METHODS
// CARD or WIRE
//-----------------------------------------------------------------------------------------
$trx->addData('methods', array('CARD'));


// REDIRECT URLs
//-----------------------------------------------------------------------------------------

// common URL for all result
$trx->addData('url', $config['URL']);

// uniq URL for every result type
/*
    $trx->addGroupData('urls', 'success', $config['URLS_SUCCESS']);
    $trx->addGroupData('urls', 'fail', $config['URLS_FAIL']);
    $trx->addGroupData('urls', 'cancel', $config['URLS_CANCEL']);
    $trx->addGroupData('urls', 'timeout', $config['URLS_TIMEOUT']);
*/


// INVOICE DATA
//-----------------------------------------------------------------------------------------

$trx->addGroupData('invoice', 'name', 'SimplePay V2 Tester');
//$trx->addGroupData('invoice', 'company', '');
$trx->addGroupData('invoice', 'country', 'hu');
$trx->addGroupData('invoice', 'state', 'Budapest');
$trx->addGroupData('invoice', 'city', 'Budapest');
$trx->addGroupData('invoice', 'zip', '1111');
$trx->addGroupData('invoice', 'address', 'Address 1');
//$trx->addGroupData('invoice', 'address2', '');
//$trx->addGroupData('invoice', 'phone', '06203164978');


// DELIVERY DATA
//-----------------------------------------------------------------------------------------
/*
$trx->addGroupData('delivery', 'name', 'SimplePay V2 Tester');
$trx->addGroupData('delivery', 'company', '');
$trx->addGroupData('delivery', 'country', 'hu');
$trx->addGroupData('delivery', 'state', 'Budapest');
$trx->addGroupData('delivery', 'city', 'Budapest');
$trx->addGroupData('delivery', 'zip', '1111');
$trx->addGroupData('delivery', 'address', 'Address 1');
$trx->addGroupData('delivery', 'address2', '');
$trx->addGroupData('delivery', 'phone', '06203164978');
*/


//payment starter element
// auto: (immediate redirect)
// button: (default setting)
// link: link to payment page
//-----------------------------------------------------------------------------------------
$trx->formDetails['element'] = 'button';


//create transaction in SimplePay system
//-----------------------------------------------------------------------------------------
$trx->runStart();


//create html form for payment using by the created transaction
//-----------------------------------------------------------------------------------------
$trx->getHtmlForm();


//print form
//-----------------------------------------------------------------------------------------
print $trx->returnData['form'];


// test data
//-----------------------------------------------------------------------------------------
print "API REQUEST";
print "<pre>";
print_r($trx->getTransactionBase());
print "</pre>";

print "API RESULT";
print "<pre>";
print_r($trx->getReturnData());
print_r($trx);
print "</pre>";

//token sotore for testing purpose
//-----------------------------------------------------------------------------------------
if (isset($trx->transactionBase['recurring'])) {
    include_once 'src/SimplePayV21TokenData.php';
    $store = new RecurringStore;
    $store->transaction = $trx->getReturnData();
    $store->transactionBase = $trx->getTransactionBase();
    $store->storeNewTokens();
}

